Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(590)

Unified Diff: pkg/analysis_services/lib/completion/completion_computer.dart

Issue 465843002: respect show/hide combinators when generating suggestions (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_services/lib/completion/completion_computer.dart
diff --git a/pkg/analysis_services/lib/completion/completion_computer.dart b/pkg/analysis_services/lib/completion/completion_computer.dart
index 0962cdfb57fc92073fc9cb729f4573a91f520c12..0903c9e41c6f9ac6e9b45b384ac0a430f7db40c3 100644
--- a/pkg/analysis_services/lib/completion/completion_computer.dart
+++ b/pkg/analysis_services/lib/completion/completion_computer.dart
@@ -23,20 +23,22 @@ abstract class CompletionComputer {
SearchEngine searchEngine;
/**
* Computes the initial set of [CompletionSuggestion]s based on information
* already cached in the analysis context. This method should execute
* quickly and not block waiting for any analysis.
* Returns `true` if the computer's work is complete
* or `false` if [computeFull] should be called to complete the work.
*/
- bool computeFast(CompilationUnit unit,
+ bool computeFast(CompilationUnit unit, AstNode node,
scheglov 2014/08/12 05:02:21 Would you please document [node]?
danrubel 2014/08/12 14:52:56 It is documented in the comment, but perhaps not c
List<CompletionSuggestion> suggestions);
/**
* Computes [CompletionSuggestion]s for the specified position in the source.
* Returns `true` if the receiver modified the list of suggestions.
*/
- Future<bool> computeFull(CompilationUnit unit,
+ Future<bool> computeFull(CompilationUnit unit, AstNode node,
List<CompletionSuggestion> suggestions);
}
@@ -23,20 +23,22 @@ abstract class CompletionComputer {
SearchEngine searchEngine;
/**
- * Computes the initial set of [CompletionSuggestion]s based on information
- * already cached in the analysis context. This method should execute
- * quickly and not block waiting for any analysis.
+ * Given the compilation unit and the node at the completion offset,
+ * this computes the initial set of [CompletionSuggestion]s based on
+ * information already cached in the analysis context.
+ * This method should execute quickly and not block waiting for any analysis.
* Returns `true` if the computer's work is complete
* or `false` if [computeFull] should be called to complete the work.
@@ -23,20 +23,22 @@ abstract class CompletionComputer {
List<CompletionSuggestion> suggestions);
/**
- * Computes [CompletionSuggestion]s for the specified position in the source.
- * Returns `true` if the receiver modified the list of suggestions.
+ * Given the resolved compilation unit and the node at the completion offset,
+ * this computes [CompletionSuggestion]s for the specified position in the
+ * source. Returns `true` if the receiver modified the list of suggestions.
*/

Powered by Google App Engine
This is Rietveld 408576698